export declare class Transcriber {
    m_Module: ModuleCode;
    m_ClassMap: Map<string, ExportClassCode>;
    m_MethodMap: Map<string, Array<MethodCode>>;
    m_ContextMap: Map<string, LocalContext>;
    m_InlineContextMap: Map<Symbol, InlineContext>;
    m_DSLMap: Map<string, IDSL>;
    m_Plugins: Array<IPlugin>;
    Transcribe(): string;
    AddDSL(name: string, dsl: IDSL): void;
    GetDSL(name: string): IDSL;
    GetLocalContext(name: string): LocalContext;
    TraverseLocalContext(callback: TraverseLocalContextCallback): void;
    TraverseInlineContext(callback: TraverseInlineContextCallback): void;
    GetClass(name: string): ExportClassCode;
    TraverseMethod(callback: TraverseMethodCallback): void;
    constructor(_module: string);
}
export interface IDSL {
    Transcribe?(block: Array<Statement>, path?: NodePath<FunctionDeclaration> | NodePath<BlockStatement>): Array<Statement>;
    InplaceTranscribe?(literal: NodePath<TemplateLiteral>, type: string): Expression;
    m_Merge?: boolean;
}
export interface IPlugin {
    Transcribe(): void;
}
export interface ITranscriber {
    Transcribe: () => string;
    AddDSL: (name: string, dsl: IDSL) => void;
    GetDSL: (name: string) => IDSL;
    GetClass: (name: string) => ExportClassCode;
    GetLocalContext: (name: string) => LocalContext;
    TraverseMethod: (callback: TraverseMethodCallback) => void;
    TraverseLocalContext: (callback: TraverseLocalContextCallback) => void;
    TraverseInlineContext: (callback: TraverseInlineContextCallback) => void;
    m_Module: ModuleCode;
    m_ClassMap: Map<string, ExportClassCode>;
    m_MethodMap: Map<string, Array<MethodCode>>;
    m_ContextMap: Map<string, LocalContext>;
    m_InlineContextMap: Map<Symbol, InlineContext>;
    m_DSLMap: Map<string, IDSL>;
    m_Plugins: Array<IPlugin>;
}
export declare type TraverseLocalContextCallback = (context: LocalContext, name: string) => void;
export declare type TraverseInlineContextCallback = (context: InlineContext) => void;
export declare type TraverseMethodCallback = (methods: Array<MethodCode>, class_name: string) => void;
import { Statement, FunctionDeclaration, BlockStatement, Expression, TemplateLiteral } from "@babel/types";
import { NodePath } from "@babel/traverse";
import { ModuleCode } from "../code-object/module";
import { ExportClassCode } from "../code-object/export-class";
import { MethodCode } from "../code-object/method";
import { LocalContext } from "../code-object/local-context";
import { InlineContext } from "../code-object/inline-context";
